@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20121031';
+our $VERSION = '0.20121130';
 
-# Table last modified: 2012-10-31
+# Table last modified: 2012-11-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,19 +103,19 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|2(?:10|0[1-4])|101))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
+    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|2(?:0[1-4]|1[03])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[245]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[014589]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
-    '106' => '(?:(?:8(?:5(?:08|3[015]|4[134]|6[0-35-79]|7[136-8]|1[458]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[257-9]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
+    '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|3[13489]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689]|6[016])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|8[02]|0[1-38]|3[0-4]|5[05]|1[017]|[24][0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[0158]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|8[0235]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
+    '112' => '(?:8(?:6(?:90|0[167]|2[02579]|4[24]|7[0178]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|2[248]|0[1-35689]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[013-5]|1[02-57-9]|7[147]|2[0-2468]|5[02-57]|3[0-24589])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
@@ -124,7 +124,7 @@ our %ZIP_TABLE = (
     '121' => '(?:8(?:5(?:33|40|0[245]|2[0-4]|8[58]|5[05]|1[01])|6(?:[02]1|3[39]|8[0-2]|1[016])|7(?:01|29|1[01])|080))',
     '123' => '(?:85(?:40|8[58]|1[147]|0[135689]))',
     '124' => '(?:8(?:5(?:77|6[06]|1[018]|3[3589]|0[1-39]|8[58]|5[05]|2[024])|070))',
-    '125' => '(?:8(?:5(?:55|88|1[1-57]|0[3-8]|2[026])|60[12]))',
+    '125' => '(?:8(?:5(?:55|88|1[1-57]|0[3-8]|2[026])|601))',
     '130' => '(?:8(?:5(?:6[5-7]|7[057]|8[0348]|3[013-589]|4[358]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|0[1-589]|7[17]|3[67]|5[05]|6[068]|1[15]|4[024])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-9])|634|711))',
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[02-46-8]|0[2-6]|7[0-36]|8[0136-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[02-46-8]|0[2-6]|7[0-36]|8[0136-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|6[0-25-8]|5[05-79]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[14]|6[01])))',
@@ -152,15 +152,15 @@ our %ZIP_TABLE = (
     '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:1[015]|4[47]|3[013]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|2[0158]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
     '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:1[25]|4[013]|7[57]|2[279]|5[16-8]|8[0357]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
-    '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[013])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|6[156]|5[35])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
-    '164' => '(?:8(?:5(?:[67]7|12|30|2[25]|8[58]|5[05]|0[13-5]|4[01])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[248])|7(?:01|25)))',
+    '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[13])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|6[156]|5[35])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
+    '164' => '(?:8(?:5(?:[67]7|30|2[25]|8[58]|5[05]|0[13-5]|1[12]|4[01])|6(?:[037]8|[25]0|66|8[26]|1[17]|4[248])|7(?:01|25)))',
     '165' => '(?:8(?:555|780))',
     '166' => '(?:8(?:5(?:20|55|3[13589]|6[5-7]|4[025]|0[1-36]|8[58]|7[078])|6(?:01|10)))',
     '167' => '(?:8(?:5(?:[24]0|85|7[78]|3[34]|6[07]|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
-    '168' => '(?:8(?:5(?:[67]0|85|3[03]|5[058]|0[1-468]|2[05]|1[0-2])|6(?:01|26|[18][16])|081))',
+    '168' => '(?:8(?:5(?:[67]0|85|3[03]|5[058]|0[1-468]|2[05]|1[0-2])|6(?:01|2[06]|[18][16])|081))',
     '169' => '(?:8(?:5(?:6[018]|2[0-25-7]|8[0568]|4[013]|3[0135]|0[37-9]|1[015-7]|7[078]|5[01568])|6(?:2[04]|5[056]|7[78]|0[1358]|1[0-36]|6[1468]|4[0458]|3[179])|0(?:50|77|1[12])|7(?:[01]1|22)|228|915))',
     '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|7[067]|5[015-9]|6[0156]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|0[25]|[35][35])|0(?:55|73)|5(?:51|85))|6080))',
-    '171' => '(?:85(?:3[19]|7[027]|5[023578]|4[045]|2[0-35-8]|8[268]|1[0-2468]|6[0189]|0[1-37-9]))',
+    '171' => '(?:85(?:3[19]|7[027]|5[023578]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|8[0268]|0[1-37-9]))',
     '173' => '(?:8(?:5(?:[06]1|30|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|66|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:30|88|5[058]|6[07]|2[0146]|0[15])|6(?:01|12|46|3[369]|8[068])|7(?:[01]1|3[079]|4[0134])|860|903))',
     '175' => '(?:85(?:88|7[17]))',
@@ -178,7 +178,7 @@ our %ZIP_TABLE = (
     '187' => '(?:8(?:5(?:40|0[2357]|3[13]|5[1358]|2[02]|6[07]|8[1578]|7[078]|1[0-28])|(?:61|70)1))',
     '188' => '(?:8(?:5(?:[58]5|11)|6(?:66|80)|701))',
     '189' => '(?:85(?:[01]1|85|5[05]|2[01]))',
-    '190' => '(?:(?:8(?:5(?:3[015-79]|6[0-25-7]|5[013-578]|8[1-3689]|0[135-9]|7[1-358]|1[013-9]|4[034]|2[0-28])|6(?:66|8[0168]))|129[2357]|0192))',
+    '190' => '(?:(?:8(?:5(?:3[015-79]|5[013-578]|6[0-256]|8[1-3689]|0[135-9]|7[1-358]|1[013-9]|4[034]|2[0-28])|6(?:66|8[0168]))|129[2357]|0192))',
     '191' => '(?:8(?:5(?:20|55|0[1-35-79]|1[0-2])|6(?:60|86)))',
     '192' => '(?:(?:8(?:5(?:77|85|1[0-2568]|2[025]|6[28]|5[1368]|3[235-8]|0[125-8])|6(?:11|22|33|5[015]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-8])))',
     '193' => '(?:(?:8(?:5(?:[57]0|33|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
@@ -217,7 +217,7 @@ our %ZIP_TABLE = (
     '235' => '(?:85(?:[58]8|2[23]|0[15]))',
     '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:48|53)))',
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
-    '238' => '(?:(?:8(?:5(?:33|41|8[058]|2[02]|6[57]|5[08]|1[01])|6[18]6)|029[28]))',
+    '238' => '(?:(?:8(?:5(?:33|41|8[058]|1[013]|2[02]|6[57]|5[08])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|50|8[58])|68[68]))',
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0|15)|612)|019[2-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
@@ -231,7 +231,7 @@ our %ZIP_TABLE = (
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|39[28]|[15]92)|85(?:11|55|88)))',
     '251' => '(?:8(?:5(?:40|2[02]|5[0158]|1[0135]|6[067]|8[18]|3[014]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|5[258]|1[01]|2[125]|9[2-578])|1(?:[56]2|7[27]|9[1256]|8[1-3589]))|0(?:3(?:7[03-57]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|5[258]|1[01]|2[125]|9[2-578])|1(?:[56]2|7[27]|9[1256]|8[1-3589]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:[03]1|10|22|43|67|7[17]|5[058]|8[58])|686)|019[25-8]))',
     '254' => '(?:8(?:5(?:43|55|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
@@ -300,7 +300,7 @@ our %ZIP_TABLE = (
     '324' => '(?:(?:8(?:5(?:01|85|1[06]|5[015])|6(?:25|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
     '325' => '(?:039[23578])',
     '326' => '(?:(?:8(?:5(?:20|72|85|5[058]|1[01]|0[125])|6(?:[01]1|30|55|86))|039[235]))',
-    '327' => '(?:(?:8(?:5(?:11|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
+    '327' => '(?:(?:8(?:5(?:11|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|5[0568]|8[568]|0[1-5])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:1(?:19[3-68]|39[2-5]|292|493)|0(?:59[568]|49[28]|69[26]|195)|2(?:79[237]|19[23]|99[23]|292)|4(?:49[23]|392)|3292))',
     '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|6[4-6]|3[156]|2[35]|7[57]|1[0-2]|0[1-37-9]|8[0-3568])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:01|30|77|1[01])|7(?:15|9[67])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|8[015]|0[3568]|3[238]|1[0189]|2[29]|7[129]|5[01]|6[56])|6(?:01|69|8[68]))))',
@@ -424,7 +424,7 @@ our %ZIP_TABLE = (
     '450' => '(?:(?:8(?:5(?:40|3[0238]|2[013]|1[05]|7[57]|6[157]|8[035]|0[125])|6(?:[48]0|01|77|2[06]|1[1458]|5[01])|7(?:11|30|65))|6133))',
     '451' => '(?:8(?:5(?:[14]1|85|[56][0158]|2[0-25]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:21|44|70|0[1-3]|6[1-79])|60[1-4]))',
-    '453' => '(?:8(?:5(?:40|55|77|8[015]|1[0-258]|6[57]|2[12]|0[15]|3[039])|6(?:[01]1|62|86)|7(?:58|65|77)))',
+    '453' => '(?:8(?:5(?:40|55|77|8[015]|3[39]|1[0-258]|6[57]|2[12]|0[15])|6(?:[01]1|62|86)|7(?:58|65|77)))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[1458]5|21|30|0[15])))',
     '456' => '(?:8(?:5(?:23|30|8[057]|6[07]|1[16]|0[12]|5[56])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
@@ -538,7 +538,7 @@ our %ZIP_TABLE = (
     '567' => '(?:8(?:5(?:[34]0|[56]7|78|85|1[015]|2[0135]|0[125])|6(?:51|80)))',
     '569' => '(?:(?:8(?:5(?:33|49|77|0[135]|2[02]|[58][58]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
     '570' => '(?:8(?:5(?:39|40|0[125-7]|[58][58]|1[15])|6(?:[68]6|34|77)))',
-    '571' => '(?:8(?:5(?:[45]5|67|71|0[347]|8[05])|6(?:33|86)))',
+    '571' => '(?:8(?:5(?:[45]5|67|71|8[05]|0[2-47])|6(?:33|86)))',
     '572' => '(?:85(?:40|67|8[01589]|2[28]|3[013]|7[02]|5[0158]|0[1578]|1[01]))',
     '573' => '(?:(?:8(?:5(?:11|34|73)|666)|10(?:[34]0|01)|019[25]))',
     '574' => '(?:85(?:01|55|3[04]))',
@@ -567,7 +567,7 @@ our %ZIP_TABLE = (
     '599' => '(?:(?:0[23]92|8531))',
     '600' => '(?:8(?:5(?:4[04]|3[03]|1[019]|5[058]|8[1568]|7[07]|6[067]|0[1-35])|6(?:77|5[12]|8[68]|6[56])|7(?:11|87)))',
     '601' => '(?:(?:8(?:5(?:01|20|42|3[03]|8[58]|5[05]|1[01])|680)|0(?:292|797)|1(?:192|495)))',
-    '602' => '(?:8(?:5(?:[01]1|[27]0|55|66|8[058])|611))',
+    '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|611))',
     '603' => '(?:85(?:11|22|55|77|88))',
     '604' => '(?:8(?:5(?:20|8[058]|7[178]|6[07]|5[01568]|1[01]|0[1-358])|666|798))',
     '605' => '(?:8(?:5[01]1|686))',
@@ -709,7 +709,7 @@ our %ZIP_TABLE = (
     '750' => '(?:(?:8(?:5(?:0[1-8]|2[0145]|1[0-3578])|6(?:10|0[1-378]))|069[23]|119[23]))',
     '751' => '(?:8(?:5(?:10|0[38])|650))',
     '752' => '(?:8(?:5(?:01|85|5[58]|1[01])|60[19]))',
-    '753' => '(?:(?:8(?:5(?:40|88|7[07]|5[58]|1[0-57-9]|0[1-46-9]|3[0-8]|2[0-25689])|65[034])|029[23]))',
+    '753' => '(?:(?:8(?:5(?:40|88|7[07]|3[013-8]|5[58]|1[0-57-9]|0[1-46-9]|2[0-25689])|65[034])|029[23]))',
     '754' => '(?:(?:8(?:5(?:[358]5|[01]1|22)|6(?:01|1[01]))|1(?:19[23]|292)|0291))',
     '755' => '(?:(?:8(?:5(?:22|43|8[058]|6[067]|1[01]|5[0457]|0[125])|6(?:33|42|0[19]|2[25]|1[01]))|019[25]))',
     '756' => '(?:8(?:5(?:85|0[12])|60[12]))',
@@ -750,7 +750,7 @@ our %ZIP_TABLE = (
     '791' => '(?:(?:8(?:5(?:51|2[3-578]|1[0-36-8]|3[01568]|0[125-8])|6(?:0[34]|7[1257]))|0(?:2(?:8[018]|9[257])|3(?:85|9[23578])|59[34])|3(?:19[2-8]|29[235]|[35]92)|(?:45|1[17])92|219[135]))',
     '792' => '(?:8(?:5(?:43|67|1[018]|8[0568]|5[05]|2[01]|0[15])|6(?:14|70|86)))',
     '793' => '(?:8(?:5(?:[58]5|0[19]|1[05])|601))',
-    '794' => '(?:(?:8(?:5(?:82|1[018]|0[28])|6(?:0[1278]|1[14]))|2(?:39[25]|59[23]|[12]92)|1(?:39[23]|[14]92)|019[23]))',
+    '794' => '(?:(?:8(?:5(?:82|0[28]|1[18])|6(?:0[1278]|1[14]))|2(?:39[25]|59[23]|[12]92)|1(?:39[23]|[14]92)|019[23]))',
     '795' => '(?:(?:8(?:5(?:0[124-8]|1[01])|60[1-3])|0392))',
     '796' => '(?:(?:0(?:29[235]|495|892)|850[12]))',
     '797' => '(?:(?:(?:02|1[257])92|85[01]1))',
@@ -775,7 +775,7 @@ our %ZIP_TABLE = (
     '816' => '(?:8(?:5(?:[13]0|[67]7|01|[58][05])|666))',
     '817' => '(?:(?:1(?:[26]92|797)|85(?:20|1[07])))',
     '818' => '(?:(?:8(?:5(?:34|55|67|0[1-3]|1[69]|7[178]|4[09]|8[58])|6(?:42|86|6[68]))|019[2-578]))',
-    '819' => '(?:(?:85(?:11|33|85|5[0-258]|0[124])|1(?:19[235]|[36]92)|0(?:39[25]|192)))',
+    '819' => '(?:(?:85(?:11|33|85|5[0-258]|0[124])|1(?:19[235]|[36]92)|0(?:19[23]|395)))',
     '820' => '(?:(?:8(?:5(?:[24]0|33|55|1[02367]|0[125-8])|60[1-357])|0(?:[2357]92|69[36])|119[23]))',
     '821' => '(?:8501)',
     '822' => '(?:(?:1(?:29[236]|19[23]|492)|8(?:5(?:[58]5|01)|666)))',
